@@ -9,6 +9,7 @@ then
 fi
 
 echo "Killing all applications..."
+killall openvpn
 killall udhcpc
 killall udhcpd
 killall lighttpd
@@ -17,6 +18,7 @@ killall resetIP.sh
 killall pppoe
 killall pppd
 killall hostapd
+killall bbmd
 echo "Starting at root..."
 cd /
 
