@@ -11,6 +11,7 @@ then
 fi
 
 echo "Killing all applications..."
+killall openvpn
 killall udhcpc
 killall udhcpd
 killall lighttpd
@@ -19,6 +20,7 @@ killall resetIP.sh
 killall pppoe
 killall pppd
 killall hostapd
+killall bbmd
 # Make sure we're at root level.
 #
 cd /
